@@ -3,9 +3,10 @@
 import curses
 from itertools import count
 from subprocess import Popen, PIPE
+from sys import platform
 
 
-__version__ = "0.1"
+__version__ = "0.1.1"
 
 gunicorns = {} # gunicorn master process names/pids.
 selected_pid = None # Process ID of currently selected gunicorn master process.
@@ -22,6 +23,11 @@ screen_width = None
 foreground_colour = curses.COLOR_BLACK
 background_colour = curses.COLOR_BLUE
 
+if platform == "darwin":
+    PS_ARGS = ["ps", "-fx"]
+else:
+    PS_ARGS = ["ps", "x", "-Fe"]
+
 
 def send_signal(signal):
     """
@@ -63,7 +69,7 @@ def update_gunicorns():
     tick = 0
     for pid in gunicorns:
         gunicorns[pid].update({"workers": 0, "mem": 0})
-    ps = Popen(["ps", "x", "-Fe"], stdout=PIPE).communicate()[0].split("\n")
+    ps = Popen(PS_ARGS, stdout=PIPE).communicate()[0].split("\n")
     headings = ps.pop(0).split()
     name_col = headings.index("CMD")
     num_cols = len(headings) - 1
@@ -206,19 +212,23 @@ if __name__ == "__main__":
     curses.noecho()
     stdscr.keypad(True)
     stdscr.nodelay(True)
-    curses.curs_set(False)
-    # Run main event loop until quit.
-    while True:
-        try:
-            update_gunicorns()
-            handle_keypress(stdscr)
-            display_output(stdscr)
-            curses.napms(int(screen_delay * 1000))
-        except KeyboardInterrupt:
-            break
-    # Tear down curses.
-    curses.nocbreak()
-    stdscr.keypad(False)
-    curses.echo()
-    curses.endwin()
-
+    try:
+        curses.curs_set(False)
+    except:
+        pass
+    try:
+        # Run main event loop until quit.
+        while True:
+            try:
+                update_gunicorns()
+                handle_keypress(stdscr)
+                display_output(stdscr)
+                curses.napms(int(screen_delay * 1000))
+            except KeyboardInterrupt:
+                break
+    finally:
+        # Tear down curses.
+        curses.nocbreak()
+        stdscr.keypad(False)
+        curses.echo()
+        curses.endwin()
